var indexSectionsWithContent =
{
  0: "acdefgikmoprstv",
  1: "acdfgikmos",
  2: "r",
  3: "cdeimpstv"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "functions",
  3: "variables"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Functions",
  3: "Variables"
};

